==> ttk-app-core-2.0.0.tgz: package/mock.js <==
//note-start
//note-start和note-end之间的内容用脚手架匹配，请不要再该区域书写内容，在执行ttk reset过程中会被删除
import './apps/edf/ttk-edf-app-card-account/mock.js';
import './apps/edf/ttk-edf-app-card-currency/mock.js';
import './apps/edf/ttk-edf-app-card-customer/mock.js';
import './apps/edf/ttk-edf-app-card-department/mock.js';
import './apps/edf/ttk-edf-app-card-inventory/mock.js';
import './apps/edf/ttk-edf-app-card-project/mock.js';
import './apps/edf/ttk-edf-app-card-supplier/mock.js';
import './apps/edf/ttk-edf-app-card-userdefinecard/mock.js';
import './apps/edf/ttk-edf-app-column/mock.js';
import './apps/edf/ttk-edf-app-column/apps/edfx-app-column-detail/mock.js';
import './apps/edf/ttk-edf-app-column/apps/edfx-app-column-setting/mock.js';
import './apps/edf/ttk-edf-app-column/apps/edfx-app-column-type/mock.js';
import './apps/edf/ttk-edf-app-company-manage/mock.js';
import './apps/edf/ttk-edf-app-company-manage/apps/ttk-edf-app-company-manage-add/mock.js';
import './apps/edf/ttk-edf-app-devtools/mock.js';
import './apps/edf/ttk-edf-app-enum/mock.js';
import './apps/edf/ttk-edf-app-enum/apps/edfx-app-tree-table-detail/mock.js';
import './apps/edf/ttk-edf-app-enum/apps/edfx-app-tree-table-type/mock.js';
import './apps/edf/ttk-edf-app-forgot-password/mock.js';
import './apps/edf/ttk-edf-app-home/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-hot-search-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-market-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-sale-proportion-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-sale-trend-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-sale-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-trade-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-visit-widget/mock.js';
import './apps/edf/ttk-edf-app-hotloader/mock.js';
import './apps/edf/ttk-edf-app-iframe/mock.js';
import './apps/edf/ttk-edf-app-im/mock.js';
import './apps/edf/ttk-edf-app-login/mock.js';
import './apps/edf/ttk-edf-app-my-setting/mock.js';
import './apps/edf/ttk-edf-app-my-setting/apps/ttk-edf-app-my-setting-change-mobile/mock.js';
import './apps/edf/ttk-edf-app-my-setting/apps/ttk-edf-app-my-setting-change-password/mock.js';
import './apps/edf/ttk-edf-app-notice/mock.js';
import './apps/edf/ttk-edf-app-operation/mock.js';
import './apps/edf/ttk-edf-app-pagestyle/mock.js';
import './apps/edf/ttk-edf-app-portal/mock.js';
import './apps/edf/ttk-edf-app-portal-hor/mock.js';
import './apps/edf/ttk-edf-app-portal-menu/mock.js';
import './apps/edf/ttk-edf-app-portal-menu-detail/mock.js';
import './apps/edf/ttk-edf-app-register/mock.js';
import './apps/edf/ttk-edf-app-register/apps/ttk-edf-app-agreement/mock.js';
import './apps/edf/ttk-edf-app-role/mock.js';
import './apps/edf/ttk-edf-app-role-auth/mock.js';
import './apps/edf/ttk-edf-app-voucher/apps/ttk-edf-app-voucher-detail-setting/mock.js';
import './apps/edf/ttk-edf-app-voucher/apps/ttk-edf-app-voucher-setting/mock.js';
import './apps/test/app-test/mock.js';
//note-end

==> ttk-app-core-2.1.3.tgz: package/mock.js <==
//note-start
//note-start和note-end之间的内容用脚手架匹配，请不要再该区域书写内容，在执行ttk reset过程中会被删除
import './apps/edf/ttk-edf-app-card-account/mock.js';
import './apps/edf/ttk-edf-app-card-currency/mock.js';
import './apps/edf/ttk-edf-app-card-customer/mock.js';
import './apps/edf/ttk-edf-app-card-department/mock.js';
import './apps/edf/ttk-edf-app-card-inventory/mock.js';
import './apps/edf/ttk-edf-app-card-project/mock.js';
import './apps/edf/ttk-edf-app-card-supplier/mock.js';
import './apps/edf/ttk-edf-app-card-userdefinecard/mock.js';
import './apps/edf/ttk-edf-app-column/mock.js';
import './apps/edf/ttk-edf-app-column/apps/edfx-app-column-detail/mock.js';
import './apps/edf/ttk-edf-app-column/apps/edfx-app-column-setting/mock.js';
import './apps/edf/ttk-edf-app-column/apps/edfx-app-column-type/mock.js';
import './apps/edf/ttk-edf-app-company-manage/mock.js';
import './apps/edf/ttk-edf-app-company-manage/apps/ttk-edf-app-company-manage-add/mock.js';
import './apps/edf/ttk-edf-app-devtools/mock.js';
import './apps/edf/ttk-edf-app-enum/mock.js';
import './apps/edf/ttk-edf-app-enum/apps/edfx-app-tree-table-detail/mock.js';
import './apps/edf/ttk-edf-app-enum/apps/edfx-app-tree-table-type/mock.js';
import './apps/edf/ttk-edf-app-forgot-password/mock.js';
import './apps/edf/ttk-edf-app-home/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-hot-search-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-market-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-sale-proportion-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-sale-trend-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-sale-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-trade-widget/mock.js';
import './apps/edf/ttk-edf-app-home/apps/ttk-edf-app-visit-widget/mock.js';
import './apps/edf/ttk-edf-app-hotloader/mock.js';
import './apps/edf/ttk-edf-app-iframe/mock.js';
import './apps/edf/ttk-edf-app-im/mock.js';
import './apps/edf/ttk-edf-app-login/mock.js';
import './apps/edf/ttk-edf-app-my-setting/mock.js';
import './apps/edf/ttk-edf-app-my-setting/apps/ttk-edf-app-my-setting-change-mobile/mock.js';
import './apps/edf/ttk-edf-app-my-setting/apps/ttk-edf-app-my-setting-change-password/mock.js';
import './apps/edf/ttk-edf-app-notice/mock.js';
import './apps/edf/ttk-edf-app-operation/mock.js';
import './apps/edf/ttk-edf-app-pagestyle/mock.js';
import './apps/edf/ttk-edf-app-portal/mock.js';
import './apps/edf/ttk-edf-app-portal/mock.js';
import './apps/edf/ttk-edf-app-portal-menu/mock.js';
import './apps/edf/ttk-edf-app-portal-menu-detail/mock.js';
import './apps/edf/ttk-edf-app-register/mock.js';
import './apps/edf/ttk-edf-app-register/apps/ttk-edf-app-agreement/mock.js';
import './apps/edf/ttk-edf-app-role/mock.js';
import './apps/edf/ttk-edf-app-role-auth/mock.js';
import './apps/edf/ttk-edf-app-voucher/apps/ttk-edf-app-voucher-detail-setting/mock.js';
import './apps/edf/ttk-edf-app-voucher/apps/ttk-edf-app-voucher-setting/mock.js';
import './apps/test/app-test/mock.js';
//note-end


import './apps/test/ttk-tax-app-vattaxpayer/mock.js';
import './apps/test/ttk-tax-app-vattaxpayer/apps/ttk-tax-app-select/mock.js';
import './apps/test/ttk-tax-app-vattaxpayer/apps/ttk-tax-app-zzsjmssbmxb/mock.js';
import './apps/test/ttk-tax-app-vattaxpayer/apps/ttk-tax-app-zzsjmssbmxb-beijing/mock.js';
import './apps/test/ttk-tax-app-vattaxpayer/apps/ttk-tax-app-zzssyyxgmnsr/mock.js';
import './apps/test/ttk-tax-app-vattaxpayer/apps/ttk-tax-app-zzsxgmfjssb/mock.js';
import './apps/test/ttk-tax-app-vattaxpayer/apps/ttk-tax-app-zzsxgmflzl/mock.js';
import './apps/test/ttk-tax-app-vattaxpayer/apps/ttk-tax-app-zzsxgmkcxmqd/mock.js';
import './apps/test/ttk-tax-app-vattaxpayer/apps/ttk-tax-app-zzsxgmxsbdcqkb/mock.js';
